@@ -12,6 +12,10 @@
 #'   districts. it can be a list of \code{antaresData} objects. 
 #'   In this case, one chart is created for each object. 
 #'   Can also contains opts who refer to a h5 file or list of opts.
+#' @param refStudy
+#'   An object of class \code{antaresData} created with function 
+#'   \code{\link[antaresRead]{readAntares}} containing data for areas and or
+#'   districts. Can also contains an opts who refer to a h5 file.
 #' @param stack
 #'   Name of the stack to use. One can visualize available stacks with 
 #'   \code{prodStackAliases}
@@ -64,7 +68,7 @@
 #' @param name
 #'   name of the stack to create or update
 #' @param variables
-#'   A named list of expressions created with \code{\link[base]{alist}}. The
+#'   A named list of expressions created with \code{\link[base:list]{alist}}. The
 #'   name of each element is the name of the variable to draw in the stacked
 #'   graph. The element itself is an expression explaining how to compute the
 #'   variable (see examples).
@@ -73,7 +77,7 @@
 #'   \code{variables} is an alias, then this argument should be \code{NULL} in 
 #'   order to use default colors.
 #' @param lines
-#'   A named list of expressions created with \code{\link[base]{alist}}
+#'   A named list of expressions created with \code{\link[base:list]{alist}}
 #'   indicating how to compute the curves to display on top of the stacked graph.
 #'   It should be \code{NULL} if there is no curve to trace or if parameter
 #'   \code{variables} is an alias.
@@ -91,7 +95,7 @@
 #'   of mcYears in one of studies will be selectable. If intersect, only mcYears in all
 #'   studies will be selectable.
 #' @param h5requestFiltering Contains arguments used by default for h5 request,
-#'   typically h5requestFiltering = list(select = "NUCLEAR")
+#'   typically h5requestFiltering = list(areas = "a", mcYears = 2)
 #' @param stepPlot \code{boolean}, step style for curves.
 #' @param drawPoints \code{boolean}, add points on graph
 #' @param timeSteph5 \code{character} timeStep to read in h5 file. Only for Non interactive mode.
@@ -171,6 +175,11 @@
 #' 
 #' # Compare studies
 #' prodStack(list(mydata, mydata))
+#' # Compare studies with refStudy argument 
+#' prodStack(x = myData1, refStudy = myData2)
+#' prodStack(x = myData1, refStudy = myData2, interactive = FALSE)
+#' prodStack(x = list(myData2, myData3, myData4), refStudy = myData1)
+#' prodStack(x = list(myData2, myData3, myData4), refStudy = myData1, interactive = FALSE)
 #' 
 #' 
 #' # Use h5 opts
@@ -190,8 +199,13 @@
 #' # Compare 2 studies
 #' prodStack(x = list(opts, opts2))
 #' 
+#' # Compare 2 studies with argument refStudies 
+#' prodStack(x = opts, refStudy = opts2)
+#' prodStack(x = opts, refStudy = opts2, interactive = FALSE, mcYearh5 = 2, areas = myArea) 
+#' prodStack(x = opts, refStudy = opts2, h5requestFiltering = list(areas = myArea, 
+#' mcYears = 2))
 #' 
-#'                 
+#'                
 #' }
 #' 
 #' @export
@@ -208,58 +222,50 @@ prodStack <- function(x,
                       legend = TRUE, legendId = sample(1e9, 1),
                       groupId = legendId,
                       legendItemsPerRow = 5,
-                      width = NULL, height = NULL, xyCompare = c("union","intersect"),
+                      width = NULL, height = NULL, xyCompare = c("union", "intersect"),
                       h5requestFiltering = list(), stepPlot = FALSE, drawPoints = FALSE,
                       timeSteph5 = "hourly",
                       mcYearh5 = NULL,
                       tablesh5 = c("areas", "links"), language = "en", 
-                      hidden = NULL, ...) {
+                      hidden = NULL,
+                      refStudy = NULL,
+                      ...) {
   
-  if(!is.null(compare) && !interactive){
-    stop("You can't use compare in no interactive mode")
-  }
+  #we can hide these values
+  prodStackValHidden <- c("H5request", "timeSteph5", "tables", "mcYearH5", "mcYear", "main", "dateRange", 
+                               "stack", "unit", "areas", "legend", "stepPlot", "drawPoints")
+  prodStackValCompare <- c("mcYear", "main", "unit", "areas", "legend", "stack", "stepPlot", "drawPoints")
   
-  # Check language
-  if(!language %in% availableLanguages_labels){
-    stop("Invalid 'language' argument. Must be in : ", paste(availableLanguages_labels, collapse = ", "))  
-  }
+  listParamsCheck <- list(
+    x = x,
+    compare = compare, 
+    interactive = interactive, 
+    language = language, 
+    hidden = hidden,
+    valHidden = prodStackValHidden, 
+    valCompare = prodStackValCompare,
+    mcYear = mcYear,
+    h5requestFiltering = h5requestFiltering,
+    compareOptions = compareOpts
+  )
   
-  # Check hidden
-  .validHidden(hidden, c("H5request", "timeSteph5", "tables", "mcYearH5", "mcYear", "main", "dateRange", 
-                         "stack", "unit", "areas", "legend", "stepPlot", "drawPoints"))
-  # Check compare
-  .validCompare(compare,  c("mcYear", "main", "unit", "areas", "legend", "stack", "stepPlot", "drawPoints"))
+  listParamsCheck <- .check_params_A_get_cor_val(listParamsCheck)
+  x <- listParamsCheck$x
+  compare <- listParamsCheck$compare
+  compareOptions <- listParamsCheck$compareOptions
+  h5requestFiltering <- listParamsCheck$h5requestFiltering
+  mcYear <- listParamsCheck$mcYear
   
   xyCompare <- match.arg(xyCompare)
   unit <- match.arg(unit)
-  if (is.null(mcYear)) mcYear <- "average"
-  
-  if(!is.null(compare) && "list" %in% class(x)){
-    if(length(x) == 1) x <- list(x[[1]], x[[1]])
-  }
-  if(!is.null(compare) && ("antaresData" %in% class(x)  | "simOptions" %in% class(x))){
-    x <- list(x, x)
-  }
-  
-  # .testXclassAndInteractive(x, interactive)
-  
-  h5requestFiltering <- .convertH5Filtering(h5requestFiltering = h5requestFiltering, x = x)
-  
-  compareOptions <- .compOpts(x, compare)
-  if(is.null(compare)){
-    if(compareOptions$ncharts > 1){
-      compare <- ""
-    }
-  }
   
   init_areas <- areas
   init_dateRange <- dateRange
-  
+
   processFun <- function(x) {
     
+    .check_x_antaresData(x)
     # Check that input contains area or district data
-    if (!is(x, "antaresData")) stop("'x' should be an object of class 'antaresData created with readAntares()'")
-    
     if (is(x, "antaresDataTable")) {
       if (!attr(x, "type") %in% c("areas", "districts")) stop("'x' should contain area or district data")
     } else if (is(x, "antaresDataList")) {
@@ -287,7 +293,7 @@ prodStack <- function(x,
       stackOpts <- .aliasToStackOptions(stack)
       dt <- x[area %in% areas]
       
-      if(length(mcYear) == 0){
+      if (length(mcYear) == 0){
         mcYear <- "average"
       }
       if (mcYear == "average") dt <- synthesize(dt)
@@ -298,7 +304,7 @@ prodStack <- function(x,
         .printWarningMcYear()
       }
       
-      if("annual" %in% attr(dt, "timeStep")){
+      if ("annual" %in% attr(dt, "timeStep")){
         dateRange <- NULL
       }
       
@@ -306,7 +312,7 @@ prodStack <- function(x,
         dt <- dt[as.Date(.timeIdToDate(dt$timeId, timeStep, opts = opts)) %between% dateRange]
       }
       
-      if(nrow(dt) == 0){
+      if (nrow(dt) == 0){
         return (combineWidgets(.getLabelLanguage("No data for this selection", language)))
       }
       
@@ -342,7 +348,7 @@ prodStack <- function(x,
                               dateRange = dateRange,
                               stepPlot = stepPlot, drawPoints = drawPoints, language = language), silent = TRUE)
       
-      if("try-error" %in% class(p)){
+      if ("try-error" %in% class(p)){
         return (
           combineWidgets(paste0(.getLabelLanguage("Can't visualize stack", language), " '", stack, "'<br>", p[1]))
         )
@@ -369,24 +375,30 @@ prodStack <- function(x,
       dateRange = init_dateRange
     )
   }
+  
   if (!interactive) {
-    x <- .cleanH5(x, timeSteph5, mcYearh5, tablesh5, h5requestFiltering)
-    
-    
-    params <- .getDataForComp(x = .giveListFormat(x),
-                              y = NULL, compare = compare,
-                              compareOpts = compareOptions,
+    listParamH5NoInt <- list(
+      timeSteph5 = timeSteph5,
+      mcYearh5 = mcYearh5,
+      tablesh5 = tablesh5, 
+      h5requestFiltering = h5requestFiltering
+    )
+    params <- .getParamsNoInt(x = x, 
+                              refStudy = refStudy, 
+                              listParamH5NoInt = listParamH5NoInt, 
+                              compare = compare, 
+                              compareOptions = compareOptions, 
                               processFun = processFun)
     
     
-    
-    L_w <- lapply(params$x, function(X){
-      X$plotWithLegend(1, areas, main, unit,
-                       stack, params$x[[1]]$dateRange,
-                       mcYear, legend, stepPlot, drawPoints)
+    L_w <- lapply(seq_along(params$x), function(i){
+      myData <- params$x[[i]]
+      myData$plotWithLegend(i, areas, main, unit,
+                            stack, params$x[[1]]$dateRange,
+                            mcYear, legend, stepPlot, drawPoints)
     })
-    return(combineWidgets(list = L_w))
     
+    return(combineWidgets(list = L_w))
   } else {
     # just init for compare & compareOpts
     # init_params <- .getDataForComp(x, y, compare, compareOpts, function(x) {})
@@ -408,8 +420,8 @@ prodStack <- function(x,
   manipulateWidget(
     {
       .tryCloseH5()
-      if(.id <= length(params$x)){
-        widget <- params$x[[max(1,.id)]]$plotWithLegend(.id, areas, main,
+      if (.id <= length(params$x)){
+        widget <- params$x[[max(1, .id)]]$plotWithLegend(.id, areas, main,
                                                         unit, stack, dateRange,
                                                         mcYear, legend,
                                                         stepPlot, drawPoints)
@@ -434,7 +446,7 @@ prodStack <- function(x,
       label = .getLabelLanguage("H5request", language),
       timeSteph5 = mwSelect(
         {
-          if(length(paramsH5) > 0){
+          if (length(paramsH5) > 0){
             choices = paramsH5$timeStepS
             names(choices) <- sapply(choices, function(x) .getLabelLanguage(x, language))
             choices
@@ -442,14 +454,14 @@ prodStack <- function(x,
             NULL
           }
         }, 
-        value =  if(.initial) {paramsH5$timeStepS[1]}else{NULL},
+        value =  if (.initial) {paramsH5$timeStepS[1]}else{NULL},
         label = .getLabelLanguage("timeStep", language), 
         multiple = FALSE, .display = !"timeSteph5" %in% hidden
       ),
       tables = mwSelect(
         {
-          if(length(paramsH5) > 0){
-            choices = paramsH5[["tabl"]][paramsH5[["tabl"]]%in%c("areas", "districts")]
+          if (length(paramsH5) > 0){
+            choices = paramsH5[["tabl"]][paramsH5[["tabl"]] %in% c("areas", "districts")]
             names(choices) <- sapply(choices, function(x) .getLabelLanguage(x, language))
             choices
           } else {
@@ -457,7 +469,7 @@ prodStack <- function(x,
           }
         },
         value = {
-          if(.initial) {paramsH5[["tabl"]][paramsH5[["tabl"]]%in%c("areas", "districts")][1]}else{NULL}
+          if (.initial) {paramsH5[["tabl"]][paramsH5[["tabl"]] %in% c("areas", "districts")][1]}else{NULL}
         }, 
         label = .getLabelLanguage("table", language), 
         multiple = FALSE, .display = !"tables" %in% hidden
@@ -469,7 +481,7 @@ prodStack <- function(x,
           ch
         },
         value = {
-          if(.initial){paramsH5[["mcYearS"]][1]}else{NULL}
+          if (.initial){paramsH5[["mcYearS"]][1]}else{NULL}
         },
         label = .getLabelLanguage("mcYears to be imported", language), 
         multiple = TRUE, options = list(maxItems = 4),
@@ -484,8 +496,8 @@ prodStack <- function(x,
     ),
     
     sharerequest = mwSharedValue({
-      if(length(meanYearH5) > 0){
-        if(meanYearH5){
+      if (length(meanYearH5) > 0){
+        if (meanYearH5){
           list(timeSteph5_l = timeSteph5, mcYearh_l = NULL, tables_l = tables)
         } else {
           list(timeSteph5_l = timeSteph5, mcYearh_l = mcYearH5, tables_l = tables)
@@ -498,22 +510,24 @@ prodStack <- function(x,
     x_tranform = mwSharedValue({
       
       h5requestFilteringTp <- paramsH5$h5requestFilter
-      if(!is.null(sharerequest))
+      if (!is.null(sharerequest))
       {
-        for(i in 1:length(h5requestFilteringTp))
+        for (i in 1:length(h5requestFilteringTp))
         {
-          if(sharerequest$tables == "areas"){
+          if (sharerequest$tables == "areas"){
             h5requestFilteringTp[[i]]$districts = NULL
           }
-          if(sharerequest$tables == "districts"){
+          if (sharerequest$tables == "districts"){
             h5requestFilteringTp[[i]]$areas = NULL
           }
         }
       }
       
-      sapply(1:length(x_in),function(zz){
-        .loadH5Data(sharerequest, x_in[[zz]], h5requestFilter = h5requestFilteringTp[[zz]])
-      }, simplify = FALSE)
+      resXT <- .get_x_transform(x_in = x_in,
+                                sharerequest = sharerequest,
+                                refStudy = refStudy, 
+                                h5requestFilter = h5requestFilteringTp )
+      resXT 
     }),
     
     params = mwSharedValue({
@@ -534,27 +548,27 @@ prodStack <- function(x,
         unique(vv$x$mcYear)
       }), xyCompare)
       names(allMcY) <- allMcY
-      if(is.null(allMcY)){
+      if (is.null(allMcY)){
         allMcY <- "average"
         names(allMcY) <- .getLabelLanguage("average", language)
       }
       allMcY
     }, value = {
-      if(.initial) mcYear
+      if (.initial) mcYear
       else NULL
     }, label = .getLabelLanguage("mcYear to be displayed", language), .display = !"mcYear" %in% hidden),
     
     main = mwText(main, label = .getLabelLanguage("title", language), .display = !"main" %in% hidden),
     
     dateRange = mwDateRange(value = {
-      if(.initial){
+      if (.initial){
         res <- NULL
-        if(!is.null(params)){
+        if (!is.null(params)){
           res <- c(.dateRangeJoin(params = params, xyCompare = xyCompare, "min", tabl = table),
                    .dateRangeJoin(params = params, xyCompare = xyCompare, "max", tabl = table))
           ##Lock 7 days for hourly data
-          if(params$x[[1]]$timeStep == "hourly"){
-            if(params$x[[1]]$dateRange[2] - params$x[[1]]$dateRange[1]>7){
+          if (params$x[[1]]$timeStep == "hourly"){
+            if (params$x[[1]]$dateRange[2] - params$x[[1]]$dateRange[1] > 7){
               res[1] <- params$x[[1]]$dateRange[2] - 7
             }
           }
@@ -563,8 +577,8 @@ prodStack <- function(x,
       }else{NULL}
     }, 
     min = {      
-      if(!is.null(params)){
-        if(params$x[[1]]$timeStep != "annual"){
+      if (!is.null(params)){
+        if (params$x[[1]]$timeStep != "annual"){
           .dateRangeJoin(params = params, xyCompare = xyCompare, "min", tabl = table)
         } else {
           NULL
@@ -572,8 +586,8 @@ prodStack <- function(x,
       }
     }, 
     max = {      
-      if(!is.null(params)){
-        if(params$x[[1]]$timeStep != "annual"){
+      if (!is.null(params)){
+        if (params$x[[1]]$timeStep != "annual"){
           .dateRangeJoin(params = params, xyCompare = xyCompare, "max", tabl = table)
         } else {
           NULL
@@ -597,8 +611,8 @@ prodStack <- function(x,
       }), xyCompare))
     },
     value = {
-      if(.initial){
-        if(!is.null(areas)){
+      if (.initial){
+        if (!is.null(areas)){
           areas
         } else {
           as.character(.compareOperation(lapply(params$x, function(vv){
@@ -702,7 +716,7 @@ prodStack <- function(x,
   
   dt <- data.table(timeId = x$timeId)
   for (n in names(formulas)) {
-    dt[,c(n) := x[, eval(formulas[[n]]) / switch(unit, MWh = 1, GWh = 1e3, TWh = 1e6)]]
+    dt[, c(n) := x[, eval(formulas[[n]]) / switch(unit, MWh = 1, GWh = 1e3, TWh = 1e6)]]
   }
   
   p <- .plotStack(dt, timeStep, simOptions(x), colors, lines, lineColors, lineWidth, legendId,
@@ -734,8 +748,4 @@ prodStackLegend <- function(stack = "eco2mix",
     legendItemsPerRow = legendItemsPerRow,
     legendId = legendId
   )
-}
-
-
-
-
+}
\ No newline at end of file
